<?php

use MongoDB\Client;
/**
 * This file is part of webman.
 *
 * Licensed under The MIT License
 * For full copyright and license information, please see the MIT-LICENSE.txt
 * Redistributions of files must retain the above copyright notice.
 *
 * @author    walkor<walkor@workerman.net>
 * @copyright walkor<walkor@workerman.net>
 * @link      http://www.workerman.net/
 * @license   http://www.opensource.org/licenses/mit-license.php MIT License
 */

return [
    'default' => [
        'handlers' => [
            [
                'class' => Monolog\Handler\RotatingFileHandler::class,
                'constructor' => [
                    runtime_path() . '/logs/webman.log',
                    env('LOG_MAX_FIlES', 7), //$maxFiles
                    Monolog\Level::Debug,
                ],
                'formatter' => [
                    'class' => Monolog\Formatter\LineFormatter::class,
                    'constructor' => [null, 'Y-m-d H:i:s', true],
                ],
            ], [
                'class' => Monolog\Handler\MongoDBHandler::class,
                'constructor' => [
                    new Client(env('MONGOLOG_URL', 'mongodb://localhost:27017')),
                    env('MONGOLOG_DATABASE', 'log'),
                    'default',
                    Monolog\Level::Debug,
                ],
            ]
        ],
    ],
    'debug' => [
        'handlers' => [
            [
                'class' => Monolog\Handler\RotatingFileHandler::class,
                'constructor' => [
                    runtime_path() . '/logs/debug/debug.log',
                    env('LOG_MAX_FILES_DEBUG') ?: env('LOG_MAX_FIlES') ?: 7, //$maxFiles
                    Monolog\Level::Debug,
                ],
                'formatter' => [
                    'class' => Monolog\Formatter\LineFormatter::class,
                    'constructor' => [null, 'Y-m-d H:i:s.u', true, true],
                ],
            ], [
                'class' => Monolog\Handler\MongoDBHandler::class,
                'constructor' => [
                    new Client(env('MONGOLOG_URL', 'mongodb://localhost:27017')),
                    env('MONGOLOG_DATABASE', 'log'),
                    'debug',
                    Monolog\Level::Debug,
                ],
            ], [
                // 把日志输出到控制台
                'class' => Monolog\Handler\StreamHandler::class,
                'constructor' => [
                    'php://stdout',
                    Monolog\Level::Debug,
                ],
                'formatter' => [
                    'class' => Monolog\Formatter\LineFormatter::class,
                    'constructor' => [null, 'Y-m-d H:i:s.u', true, true],
                ],
            ]
        ],
    ],
    'error' => [
        'handlers' => [
            [
                'class' => Monolog\Handler\RotatingFileHandler::class,
                'constructor' => [
                    runtime_path() . '/logs/error/error.log',
                    env('LOG_MAX_FILES_ERROR') ?: env('LOG_MAX_FIlES') ?: 7, //$maxFiles
                    Monolog\Level::Debug,
                ],
                'formatter' => [
                    'class' => Monolog\Formatter\LineFormatter::class,
                    'constructor' => [null, 'Y-m-d H:i:s.u', true, true],
                ],
            ], [
                'class' => Monolog\Handler\MongoDBHandler::class,
                'constructor' => [
                    new Client(env('MONGOLOG_URL', 'mongodb://localhost:27017')),
                    env('MONGOLOG_DATABASE', 'log'),
                    'error',
                    Monolog\Level::Debug,
                ],
            ], [
                // 把日志输出到控制台
                'class' => Monolog\Handler\StreamHandler::class,
                'constructor' => [
                    'php://stdout',
                    Monolog\Level::Debug,
                ],
                'formatter' => [
                    'class' => Monolog\Formatter\LineFormatter::class,
                    'constructor' => [null, 'Y-m-d H:i:s.u', true, true],
                ],
            ],
        ],
    ],
    // 记录请求日志
    'request' => [
        'handlers' => [
            [
                'class' => Monolog\Handler\MongoDBHandler::class,
                'constructor' => [
                    new Client(env('MONGOLOG_URL', 'mongodb://localhost:27017')),
                    env('MONGOLOG_DATABASE', 'log'),
                    'request',
                    Monolog\Level::Debug,
                ],
            ],
        ],
    ],
];
